Gestion d'un projet npm
=======================
![category](développement)
![tag](angular)

On peut utiliser npm pour créer un projet web

Pour rappel pour installer **npm** il faut installer le projet node-js

```
apt-get install libcurl4-gnutls-dev libexpat1-dev gettext zlib1g-dev libssl-dev
apt-get install make
# for npm
cd /opt
wget https://nodejs.org/dist/v6.11.0/node-v6.11.0-linux-x64.tar.xz
tar -xvf node-v6.11.0-linux-x64.tar.xz
ln -s node-v6.11.0-linux-x64 node
rm node-v6.11.0-linux-x64.tar.xz
ln -s /opt/node/bin/node /usr/bin/node
ln -s /opt/node/bin/npm /usr/bin/npm
echo "export PATH=$PATH:/opt/node/bin" >> /root/.bashrc
echo "export PATH=$PATH:/opt/node/bin" >> /home/fraoustin/.bashrc
```

Initialisation d'un projet
--------------------------

```
mkdir myproject
cd myproject
npm init
```

Puis il faut ajouter dasn package.json

```
"scripts": {
    "build": "webpack --mode production",
    "dev": "webpack-dev-server --content-base=public --open"
},
"author": {
    "name": "Frédéric Aoustin",
    "url": "https://github.com/fraoustin"
},
```

Installation des modules supplémentaires
----------------------------------------

```
npm install --save jquery
npm install --save-dev webpack
npm install --save-dev webpack-cli
npm install --save-dev webpack-dev-server
npm install --save-dev copy-webpack-plugin
npm install --save-dev raw-loader
```

Il faut aussi ajouter le fichier webpack.config.js

```
const CopyWebpackPlugin = require('copy-webpack-plugin');

module.exports = {
entry: {
    bundle: ['./app/app.js']
},
output: {
    path: __dirname + '/dist',
    filename: 'app.js'
},
module: {
    rules: [
    {
        test: /\.bpmn$/,
        use: 'raw-loader'
    }
    ]
},
plugins: [
    new CopyWebpackPlugin([
    { from: '**/*.{html,css,png}', context: 'app/' }
    ])
],
mode: 'development',
devtool: 'source-map'
};
```

```note
nous utilisons webpack pour avoir rapidement un serveur de dév et la gestion des fichiers complémentaires
```

Usage
-----

Il suffit de produire son code dans ./app/app.js puis de lancer les commandes

```
npm run dev
npm run build
```

Docker
------

Il est alors possible de générer votre application sous forme de container

Votre Dockerfile ressemble à 

```
FROM node:12 as builder
LABEL maintainer="Frederic Aoustin <fraoustin@gmail.com>"
WORKDIR /usr/src/app
COPY package*.json ./
RUN npm install
COPY . .
RUN npm run build

FROM nginx:1.17
COPY --from=builder /usr/src/app/dist /usr/share/nginx/html
```

```note
nous utilisons la possibilité du stagging pour générer notre image
```

Votre fichier .dockerignore

```
/dist
/node_modules
/package-lock.json
```

Pour construire et lancer votre container

```
docker build -t myproject .
docker run --rm -p 80:80 -t myproject
```
